==> apache-camel-2.23.0-src.zip: apache-camel-2.23.0/components/camel-disruptor/src/test/java/org/apache/camel/component/disruptor/DisruptorWaitStrategyCreationTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.camel.component.disruptor;

import com.lmax.disruptor.WaitStrategy;
import org.junit.Test;

import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertTrue;

/**
 * Tests correct creation of all supposedly possible wait strategies.
 */
public class DisruptorWaitStrategyCreationTest {
    @Test
    public void testCreateWaitStrategyInstance() throws Exception {
        for (final DisruptorWaitStrategy strategy : DisruptorWaitStrategy.values()) {
            final WaitStrategy waitStrategyInstance = strategy.createWaitStrategyInstance();

            assertNotNull(waitStrategyInstance);
            assertTrue(waitStrategyInstance instanceof WaitStrategy);
        }
    }
}

==> apache-camel-4.13.0-src.zip: apache-camel-4.13.0/components/camel-disruptor/src/test/java/org/apache/camel/component/disruptor/DisruptorWaitStrategyCreationTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.disruptor;

import com.lmax.disruptor.WaitStrategy;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertInstanceOf;
import static org.junit.jupiter.api.Assertions.assertNotNull;

/**
 * Tests correct creation of all supposedly possible wait strategies.
 */
public class DisruptorWaitStrategyCreationTest {
    @Test
    void testCreateWaitStrategyInstance() throws Exception {
        for (final DisruptorWaitStrategy strategy : DisruptorWaitStrategy.values()) {
            final WaitStrategy waitStrategyInstance = strategy.createWaitStrategyInstance();

            assertNotNull(waitStrategyInstance);
            assertInstanceOf(WaitStrategy.class, waitStrategyInstance);
        }
    }
}
